@@ -12,7 +12,7 @@ loadToken = function(credlist) {
   #
   # Returns:
   #   access.token with corresponding time stamp
-  opts = list(verbose=T)
+  opts = list(verbose=T, ssl.verifypeer = FALSE)#Fix SSL certificate problem for windows users
   a = rjson::fromJSON(RCurl::postForm("https://accounts.google.com/o/oauth2/token",
                         .opts=opts, code=credlist$c.token,
                         client_id=credlist$c.id,
